Was this page helpful?
CassAuthenticatorCallbacks¶
-
struct CassAuthenticatorCallbacks¶
Authenticator callbacks
Public Types
-
typedef void (*CassAuthenticatorInitialCallback)(CassAuthenticator *auth, void *data)¶
A callback used to initiate an authentication exchange.
Use cass_authenticator_set_response() to set the response token.
Use cass_authenticator_set_error() if an error occurred during initialization.
- Param auth:
[in]
- Param data:
[in]
-
typedef void (*CassAuthenticatorChallengeCallback)(CassAuthenticator *auth, void *data, const char *token, size_t token_size)¶
A callback used when an authentication challenge initiated by the server.
Use cass_authenticator_set_response() to set the response token.
Use cass_authenticator_set_error() if an error occurred during the challenge.
- Param auth:
[in]
- Param data:
[in]
- Param token:
[in]
- Param token_size:
[in]
-
typedef void (*CassAuthenticatorSuccessCallback)(CassAuthenticator *auth, void *data, const char *token, size_t token_size)¶
A callback used to indicate the success of the authentication exchange.
Use cass_authenticator_set_error() if an error occurred while evaluating the success token.
- Param auth:
[in]
- Param data:
[in]
- Param token:
[in]
- Param token_size:
[in]
-
typedef void (*CassAuthenticatorCleanupCallback)(CassAuthenticator *auth, void *data)¶
A callback used to cleanup resources that were acquired during the process of the authentication exchange. This is called after the termination of the exchange regardless of the outcome.
- Param auth:
[in]
- Param data:
[in]
-
typedef void (*CassAuthenticatorDataCleanupCallback)(void *data)¶
A callback used to cleanup resources.
- Param data:
[in]
Public Members
-
CassAuthenticatorInitialCallback initial_callback¶
-
CassAuthenticatorChallengeCallback challenge_callback¶
-
CassAuthenticatorSuccessCallback success_callback¶
-
CassAuthenticatorCleanupCallback cleanup_callback¶
-
typedef void (*CassAuthenticatorInitialCallback)(CassAuthenticator *auth, void *data)¶